Struct pfx::map::PrefixTreeMap

source ·
pub struct PrefixTreeMap<K, V> { /* private fields */ }
An ordered map from byte strings to arbitrary values, based on a prefix tree.

Implementations

source

impl<K, V> PrefixTreeMap<K, V>

source

pub const fn new() -> Self

Creates an empty map. The same as Default.

source

pub const fn len(&self) -> usize

Returns the number of entries (key-value pairs) in the map.

source

pub const fn is_empty(&self) -> bool

Returns true if and only if this map contains no key-value pairs.

source

pub fn get_entry<Q>(&self, key: &Q) -> Option<(&K, &V)>
where Q: ?Sized + AsRef<[u8]>,

Return a reference to the original key and value, if found.

source

pub fn get_entry_mut<Q>(&mut self, key: &Q) -> Option<(&K, &mut V)>
where Q: ?Sized + AsRef<[u8]>,

Return a reference to the original key and a mutable reference to the value, if found.

source

pub fn get<Q>(&self, key: &Q) -> Option<&V>
where Q: ?Sized + AsRef<[u8]>,

Return a reference to the value, if found.

source

pub fn get_mut<Q>(&mut self, key: &Q) -> Option<&mut V>
where Q: ?Sized + AsRef<[u8]>,

Return a mutable reference to the value, if found.

source

pub fn contains_key<Q>(&self, key: &Q) -> bool
where Q: ?Sized + AsRef<[u8]>,

Returns true if and only if the given key is found in the map.

source

pub fn remove_entry<Q>(&mut self, key: &Q) -> Option<(K, V)>
where Q: ?Sized + AsRef<[u8]>,

If the key exists in the map, return the original key and the correpsonding value.

source

pub fn remove<Q>(&mut self, key: &Q) -> Option<V>
where Q: ?Sized + AsRef<[u8]>,

If the key exists in the map, return the corresponding value.

source

pub fn iter(&self) -> Iter<'_, K, V>

An iterator over pairs of references to keys and the corresponding values.

Iteration proceeds in lexicographic order, as determined by the byte sequence of keys.

source

pub fn into_keys(self) -> IntoKeys<K, V>

An iterator over the owned keys.

Iteration proceeds in lexicographic order, as determined by the byte sequence of keys.

source

pub fn keys(&self) -> Keys<'_, K, V>

An iterator over the borrowed keys.

Iteration proceeds in lexicographic order, as determined by the byte sequence of keys.

source

pub fn into_values(self) -> IntoValues<K, V>

An iterator over the owned values.

Iteration proceeds in lexicographic order, as determined by the byte sequence of keys.

source

pub fn values(&self) -> Values<'_, K, V>

An iterator over the borrowed values.

Iteration proceeds in lexicographic order, as determined by the byte sequence of keys.

source

pub fn into_prefix_iter<Q>(self, prefix: &Q) -> NodeIntoIter<K, V>
where Q: ?Sized + AsRef<[u8]>,

An iterator over owned key-value pairs of which the key starts with the given prefix.

Iteration proceeds in lexicographic order, as determined by the byte sequence of keys.

source

pub fn prefix_iter<Q>(&self, prefix: &Q) -> NodeIter<'_, K, V>
where Q: ?Sized + AsRef<[u8]>,

An iterator over borrowed key-value pairs of which the key starts with the given prefix.

Iteration proceeds in lexicographic order, as determined by the byte sequence of keys.

source

pub fn compact(&mut self)

Removes all internal nodes that do not contain an entry.

This is useful for freeing up memory and speeding up iteration after removing many key-value pairs from the map and/or after creating many spurious nodes using the entry API (by not inserting into the nodes created by .entry()).

source

impl<K, V> PrefixTreeMap<K, V>
where K: AsRef<[u8]>,

source

pub fn entry(&mut self, key: K) -> Entry<'_, K, V>

Return an object representing the (vacant or occupied) node of the tree corresponding to the given key.

This always creates a new node, even if you don’t end up inserting into it. Avoid creating many spurious entries, or call PrefixTreeMap::compact to remove useless (empty) nodes.

source

pub fn insert(&mut self, key: K, value: V) -> Option<V>

Replaces and returns the previous value, if any.

This leaves the key in the map untouched if it already exists.

source

pub fn union<I>(self, other: I) -> Self
where I: IntoIterator<Item = (K, V)>,

Takes the union of self with another set of elements. Elements that already exist in self will be overwritten by other.

source

pub fn union_in_place<I>(&mut self, other: I)
where I: IntoIterator<Item = (K, V)>,

Takes the union of self with another set of elements. Elements that already exist in self will be overwritten by other.

source

pub fn intersection<I>(self, other: I) -> Self
where I: IntoIterator, I::Item: AsRef<[u8]>,

Takes the intersection of self with another set of elements. The intersection is solely based on the keys.

source

pub fn difference<I>(self, other: I) -> Self
where I: IntoIterator, I::Item: AsRef<[u8]>,

Removes the items corresponding to keys in other from self.

source

pub fn difference_in_place<I>(&mut self, other: I)
where I: IntoIterator, I::Item: AsRef<[u8]>,

Removes the items corresponding to keys in other from self.

source

pub fn symmetric_difference<I>(self, other: I) -> Self
where I: IntoIterator<Item = (K, V)>,

Add elements that are missing from self, and remove elements contained in self.

Containment is tested by comparing keys only. Values are not checked for equality.

source

pub fn symmetric_difference_in_place<I>(&mut self, other: I)
where I: IntoIterator<Item = (K, V)>,

Add elements that are missing from self, and remove elements contained in self.

Containment is tested by comparing keys only. Values are not checked for equality.