Struct pfx::set::PrefixTreeSet

source ·
pub struct PrefixTreeSet<T> { /* private fields */ }
An ordered set based on a prefix tree.

Implementations

source

impl<T> PrefixTreeSet<T>

source

pub const fn new() -> Self

Creates an empty set. The same as Default.

source

pub const fn len(&self) -> usize

Returns the number of items in this set.

source

pub const fn is_empty(&self) -> bool

Returns true if and only if this set is empty.

source

pub fn contains<Q>(&self, item: &Q) -> bool
where Q: ?Sized + AsRef<[u8]>,

Returns true if the key is found in the map, false otherwise.

source

pub fn remove<Q>(&mut self, key: &Q) -> bool
where Q: ?Sized + AsRef<[u8]>,

Removes a key if it existed. Returns true if a removal happened, and false if the key did not exist in the first place.

source

pub fn iter(&self) -> Iter<'_, T>

Returns an iterator over the borrowed items.

source

pub fn compact(&mut self)

Removes all internal nodes which are not useful. See the documentation of crate::map::PrefixTreeMap::compact for more details on why this is useful.

source

impl<T: AsRef<[u8]>> PrefixTreeSet<T>

source

pub fn insert(&mut self, key: T) -> bool

Inserts the key if it did not exist.

Returns true if an insertion happened, and false if the key already existed.

source

pub fn union<I>(self, other: I) -> Self
where I: IntoIterator<Item = T>,

Takes the union of self with another set of elements. Elements that already exist in self will be overwritten by other.

source

pub fn union_in_place<I>(&mut self, other: I)
where I: IntoIterator<Item = T>,

Takes the union of self with another set of elements. Elements that already exist in self will be overwritten by other.

source

pub fn intersection<I>(&self, other: I) -> Self
where I: IntoIterator<Item = T>,

Takes the intersection of self with another set of elements.

This takes &self by reference and not self by value because computing the intersection always incurs the allocation of a new set. For the same reason, there is no intersection_in_place() method, either.

source

pub fn difference<I>(self, other: I) -> Self
where I: IntoIterator, I::Item: AsRef<[u8]>,

Removes the items of other from self.

source

pub fn difference_in_place<I>(&mut self, other: I)
where I: IntoIterator, I::Item: AsRef<[u8]>,

Removes the items of other from self.

source

pub fn symmetric_difference<I>(self, other: I) -> Self
where I: IntoIterator<Item = T>,

Add elements that are missing from self, and remove elements contained in self.

source

pub fn symmetric_difference_in_place<I>(&mut self, other: I)
where I: IntoIterator<Item = T>,

Add elements that are missing from self, and remove elements contained in self.