Struct pfx::set::PrefixTreeSet
source · pub struct PrefixTreeSet<T> { /* private fields */ }Expand description
An ordered set based on a prefix tree.
Implementations
sourceimpl<T> PrefixTreeSet<T>
impl<T> PrefixTreeSet<T>
sourcepub fn contains<Q>(&self, item: &Q) -> bool
pub fn contains<Q>(&self, item: &Q) -> bool
Returns true if the key is found in the map, false otherwise.
sourcepub fn remove<Q>(&mut self, key: &Q) -> bool
pub fn remove<Q>(&mut self, key: &Q) -> bool
Removes a key if it existed. Returns true if a removal happened,
and false if the key did not exist in the first place.
sourcepub fn compact(&mut self)
pub fn compact(&mut self)
Removes all internal nodes which are not useful.
See the documentation of crate::map::PrefixTreeMap::compact
for more details on why this is useful.
sourceimpl<T: AsRef<[u8]>> PrefixTreeSet<T>
impl<T: AsRef<[u8]>> PrefixTreeSet<T>
sourcepub fn insert(&mut self, key: T) -> bool
pub fn insert(&mut self, key: T) -> bool
Inserts the key if it did not exist.
Returns true if an insertion happened, and false if the key already existed.
sourcepub fn union<I>(self, other: I) -> Selfwhere
I: IntoIterator<Item = T>,
pub fn union<I>(self, other: I) -> Selfwhere
I: IntoIterator<Item = T>,
Takes the union of self with another set of elements.
Elements that already exist in self will be overwritten by other.
sourcepub fn union_in_place<I>(&mut self, other: I)where
I: IntoIterator<Item = T>,
pub fn union_in_place<I>(&mut self, other: I)where
I: IntoIterator<Item = T>,
Takes the union of self with another set of elements.
Elements that already exist in self will be overwritten by other.
sourcepub fn intersection<I>(&self, other: I) -> Selfwhere
I: IntoIterator<Item = T>,
pub fn intersection<I>(&self, other: I) -> Selfwhere
I: IntoIterator<Item = T>,
Takes the intersection of self with another set of elements.
This takes &self by reference and not self by value because
computing the intersection always incurs the allocation of a new
set. For the same reason, there is no intersection_in_place()
method, either.
sourcepub fn difference<I>(self, other: I) -> Self
pub fn difference<I>(self, other: I) -> Self
Removes the items of other from self.
sourcepub fn difference_in_place<I>(&mut self, other: I)
pub fn difference_in_place<I>(&mut self, other: I)
Removes the items of other from self.
sourcepub fn symmetric_difference<I>(self, other: I) -> Selfwhere
I: IntoIterator<Item = T>,
pub fn symmetric_difference<I>(self, other: I) -> Selfwhere
I: IntoIterator<Item = T>,
Add elements that are missing from self, and remove elements contained in self.
sourcepub fn symmetric_difference_in_place<I>(&mut self, other: I)where
I: IntoIterator<Item = T>,
pub fn symmetric_difference_in_place<I>(&mut self, other: I)where
I: IntoIterator<Item = T>,
Add elements that are missing from self, and remove elements contained in self.